import datetime
import typing

import kubernetes.client

class V1PhotonPersistentDiskVolumeSource:
    fs_type: typing.Optional[str]
    pd_id: str
    def __init__(self, *, fs_type: typing.Optional[str] = ..., pd_id: str) -> None: ...
    def to_dict(self) -> V1PhotonPersistentDiskVolumeSourceDict: ...

class V1PhotonPersistentDiskVolumeSourceDict(typing.TypedDict, total=False):
    fsType: typing.Optional[str]
    pdID: str



import datetime
import typing

import kubernetes.client

class V2beta1MetricSpec:
    container_resource: typing.Optional[
        kubernetes.client.V2beta1ContainerResourceMetricSource
    ]
    external: typing.Optional[kubernetes.client.V2beta1ExternalMetricSource]
    object: typing.Optional[kubernetes.client.V2beta1ObjectMetricSource]
    pods: typing.Optional[kubernetes.client.V2beta1PodsMetricSource]
    resource: typing.Optional[kubernetes.client.V2beta1ResourceMetricSource]
    type: str
    def __init__(
        self,
        *,
        container_resource: typing.Optional[
            kubernetes.client.V2beta1ContainerResourceMetricSource
        ] = ...,
        external: typing.Optional[kubernetes.client.V2beta1ExternalMetricSource] = ...,
        object: typing.Optional[kubernetes.client.V2beta1ObjectMetricSource] = ...,
        pods: typing.Optional[kubernetes.client.V2beta1PodsMetricSource] = ...,
        resource: typing.Optional[kubernetes.client.V2beta1ResourceMetricSource] = ...,
        type: str
    ) -> None: ...
    def to_dict(self) -> V2beta1MetricSpecDict: ...

class V2beta1MetricSpecDict(typing.TypedDict, total=False):
    containerResource: typing.Optional[
        kubernetes.client.V2beta1ContainerResourceMetricSourceDict
    ]
    external: typing.Optional[kubernetes.client.V2beta1ExternalMetricSourceDict]
    object: typing.Optional[kubernetes.client.V2beta1ObjectMetricSourceDict]
    pods: typing.Optional[kubernetes.client.V2beta1PodsMetricSourceDict]
    resource: typing.Optional[kubernetes.client.V2beta1ResourceMetricSourceDict]
    type: str



import datetime
import typing

import kubernetes.client

class V1ResourceRequirements:
    limits: typing.Optional[dict[str, str]]
    requests: typing.Optional[dict[str, str]]
    def __init__(
        self,
        *,
        limits: typing.Optional[dict[str, str]] = ...,
        requests: typing.Optional[dict[str, str]] = ...
    ) -> None: ...
    def to_dict(self) -> V1ResourceRequirementsDict: ...

class V1ResourceRequirementsDict(typing.TypedDict, total=False):
    limits: typing.Optional[dict[str, str]]
    requests: typing.Optional[dict[str, str]]



import datetime
import typing

import kubernetes.client

class V2beta1MetricStatus:
    container_resource: typing.Optional[
        kubernetes.client.V2beta1ContainerResourceMetricStatus
    ]
    external: typing.Optional[kubernetes.client.V2beta1ExternalMetricStatus]
    object: typing.Optional[kubernetes.client.V2beta1ObjectMetricStatus]
    pods: typing.Optional[kubernetes.client.V2beta1PodsMetricStatus]
    resource: typing.Optional[kubernetes.client.V2beta1ResourceMetricStatus]
    type: str
    def __init__(
        self,
        *,
        container_resource: typing.Optional[
            kubernetes.client.V2beta1ContainerResourceMetricStatus
        ] = ...,
        external: typing.Optional[kubernetes.client.V2beta1ExternalMetricStatus] = ...,
        object: typing.Optional[kubernetes.client.V2beta1ObjectMetricStatus] = ...,
        pods: typing.Optional[kubernetes.client.V2beta1PodsMetricStatus] = ...,
        resource: typing.Optional[kubernetes.client.V2beta1ResourceMetricStatus] = ...,
        type: str
    ) -> None: ...
    def to_dict(self) -> V2beta1MetricStatusDict: ...

class V2beta1MetricStatusDict(typing.TypedDict, total=False):
    containerResource: typing.Optional[
        kubernetes.client.V2beta1ContainerResourceMetricStatusDict
    ]
    external: typing.Optional[kubernetes.client.V2beta1ExternalMetricStatusDict]
    object: typing.Optional[kubernetes.client.V2beta1ObjectMetricStatusDict]
    pods: typing.Optional[kubernetes.client.V2beta1PodsMetricStatusDict]
    resource: typing.Optional[kubernetes.client.V2beta1ResourceMetricStatusDict]
    type: str



import datetime
import typing

import kubernetes.client

class V1DeploymentStatus:
    available_replicas: typing.Optional[int]
    collision_count: typing.Optional[int]
    conditions: typing.Optional[list[kubernetes.client.V1DeploymentCondition]]
    observed_generation: typing.Optional[int]
    ready_replicas: typing.Optional[int]
    replicas: typing.Optional[int]
    unavailable_replicas: typing.Optional[int]
    updated_replicas: typing.Optional[int]
    def __init__(
        self,
        *,
        available_replicas: typing.Optional[int] = ...,
        collision_count: typing.Optional[int] = ...,
        conditions: typing.Optional[
            list[kubernetes.client.V1DeploymentCondition]
        ] = ...,
        observed_generation: typing.Optional[int] = ...,
        ready_replicas: typing.Optional[int] = ...,
        replicas: typing.Optional[int] = ...,
        unavailable_replicas: typing.Optional[int] = ...,
        updated_replicas: typing.Optional[int] = ...
    ) -> None: ...
    def to_dict(self) -> V1DeploymentStatusDict: ...

class V1DeploymentStatusDict(typing.TypedDict, total=False):
    availableReplicas: typing.Optional[int]
    collisionCount: typing.Optional[int]
    conditions: typing.Optional[list[kubernetes.client.V1DeploymentConditionDict]]
    observedGeneration: typing.Optional[int]
    readyReplicas: typing.Optional[int]
    replicas: typing.Optional[int]
    unavailableReplicas: typing.Optional[int]
    updatedReplicas: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1NetworkPolicyPort:
    port: typing.Optional[typing.Any]
    protocol: typing.Optional[str]
    def __init__(
        self,
        *,
        port: typing.Optional[typing.Any] = ...,
        protocol: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1NetworkPolicyPortDict: ...

class V1NetworkPolicyPortDict(typing.TypedDict, total=False):
    port: typing.Optional[typing.Any]
    protocol: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1alpha1StorageVersionStatus:
    common_encoding_version: typing.Optional[str]
    conditions: typing.Optional[list[kubernetes.client.V1alpha1StorageVersionCondition]]
    storage_versions: typing.Optional[
        list[kubernetes.client.V1alpha1ServerStorageVersion]
    ]
    def __init__(
        self,
        *,
        common_encoding_version: typing.Optional[str] = ...,
        conditions: typing.Optional[
            list[kubernetes.client.V1alpha1StorageVersionCondition]
        ] = ...,
        storage_versions: typing.Optional[
            list[kubernetes.client.V1alpha1ServerStorageVersion]
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1alpha1StorageVersionStatusDict: ...

class V1alpha1StorageVersionStatusDict(typing.TypedDict, total=False):
    commonEncodingVersion: typing.Optional[str]
    conditions: typing.Optional[
        list[kubernetes.client.V1alpha1StorageVersionConditionDict]
    ]
    storageVersions: typing.Optional[
        list[kubernetes.client.V1alpha1ServerStorageVersionDict]
    ]



import datetime
import typing

import kubernetes.client

class V1TCPSocketAction:
    host: typing.Optional[str]
    port: typing.Any
    def __init__(
        self, *, host: typing.Optional[str] = ..., port: typing.Any
    ) -> None: ...
    def to_dict(self) -> V1TCPSocketActionDict: ...

class V1TCPSocketActionDict(typing.TypedDict, total=False):
    host: typing.Optional[str]
    port: typing.Any



import datetime
import typing

import kubernetes.client

class V1beta1CustomResourceConversion:
    conversion_review_versions: typing.Optional[list[str]]
    strategy: str
    webhook_client_config: typing.Optional[
        kubernetes.client.ApiextensionsV1beta1WebhookClientConfig
    ]
    def __init__(
        self,
        *,
        conversion_review_versions: typing.Optional[list[str]] = ...,
        strategy: str,
        webhook_client_config: typing.Optional[
            kubernetes.client.ApiextensionsV1beta1WebhookClientConfig
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1CustomResourceConversionDict: ...

class V1beta1CustomResourceConversionDict(typing.TypedDict, total=False):
    conversionReviewVersions: typing.Optional[list[str]]
    strategy: str
    webhookClientConfig: typing.Optional[
        kubernetes.client.ApiextensionsV1beta1WebhookClientConfigDict
    ]



import datetime
import typing

import kubernetes.client

class V1alpha1Overhead:
    pod_fixed: typing.Optional[dict[str, str]]
    def __init__(self, *, pod_fixed: typing.Optional[dict[str, str]] = ...) -> None: ...
    def to_dict(self) -> V1alpha1OverheadDict: ...

class V1alpha1OverheadDict(typing.TypedDict, total=False):
    podFixed: typing.Optional[dict[str, str]]



import datetime
import typing

import kubernetes.client

class RbacV1alpha1Subject:
    api_version: typing.Optional[str]
    kind: str
    name: str
    namespace: typing.Optional[str]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        kind: str,
        name: str,
        namespace: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> RbacV1alpha1SubjectDict: ...

class RbacV1alpha1SubjectDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    kind: str
    name: str
    namespace: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1beta1FlowSchemaStatus:
    conditions: typing.Optional[list[kubernetes.client.V1beta1FlowSchemaCondition]]
    def __init__(
        self,
        *,
        conditions: typing.Optional[
            list[kubernetes.client.V1beta1FlowSchemaCondition]
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1FlowSchemaStatusDict: ...

class V1beta1FlowSchemaStatusDict(typing.TypedDict, total=False):
    conditions: typing.Optional[list[kubernetes.client.V1beta1FlowSchemaConditionDict]]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['kubernetes-stubs', 'kubernetes_ext']

package_data = \
{'': ['*'],
 'kubernetes-stubs': ['client/*',
                      'client/api/*',
                      'client/models/*',
                      'config/*']}

setup_kwargs = {
    'name': 'kubernetes-stubs',
    'version': '20.13.0',
    'description': 'Type stubs for the Kubernetes Python API client',
    'long_description': "# kubernetes-stubs\n\n[![PyPI](https://img.shields.io/pypi/v/kubernetes-stubs)](https://pypi.org/project/kubernetes-stubs/)\n\nPython type stubs for the [Kubernetes API client](https://github.com/kubernetes-client/python).\nThe version numbers of this package track upstream's. PRs to fix bugs are\nwelcomed.\n\n## Usage\n\n```\npip install kubernetes-stubs\n```\n",
    'author': 'Nikhil Benesch',
    'author_email': 'nikhil.benesch@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)



import datetime
import typing

import kubernetes.client

class V1CSIPersistentVolumeSource:
    controller_expand_secret_ref: typing.Optional[kubernetes.client.V1SecretReference]
    controller_publish_secret_ref: typing.Optional[kubernetes.client.V1SecretReference]
    driver: str
    fs_type: typing.Optional[str]
    node_publish_secret_ref: typing.Optional[kubernetes.client.V1SecretReference]
    node_stage_secret_ref: typing.Optional[kubernetes.client.V1SecretReference]
    read_only: typing.Optional[bool]
    volume_attributes: typing.Optional[dict[str, str]]
    volume_handle: str
    def __init__(
        self,
        *,
        controller_expand_secret_ref: typing.Optional[
            kubernetes.client.V1SecretReference
        ] = ...,
        controller_publish_secret_ref: typing.Optional[
            kubernetes.client.V1SecretReference
        ] = ...,
        driver: str,
        fs_type: typing.Optional[str] = ...,
        node_publish_secret_ref: typing.Optional[
            kubernetes.client.V1SecretReference
        ] = ...,
        node_stage_secret_ref: typing.Optional[
            kubernetes.client.V1SecretReference
        ] = ...,
        read_only: typing.Optional[bool] = ...,
        volume_attributes: typing.Optional[dict[str, str]] = ...,
        volume_handle: str
    ) -> None: ...
    def to_dict(self) -> V1CSIPersistentVolumeSourceDict: ...

class V1CSIPersistentVolumeSourceDict(typing.TypedDict, total=False):
    controllerExpandSecretRef: typing.Optional[kubernetes.client.V1SecretReferenceDict]
    controllerPublishSecretRef: typing.Optional[kubernetes.client.V1SecretReferenceDict]
    driver: str
    fsType: typing.Optional[str]
    nodePublishSecretRef: typing.Optional[kubernetes.client.V1SecretReferenceDict]
    nodeStageSecretRef: typing.Optional[kubernetes.client.V1SecretReferenceDict]
    readOnly: typing.Optional[bool]
    volumeAttributes: typing.Optional[dict[str, str]]
    volumeHandle: str



import datetime
import typing

import kubernetes.client

class V1DaemonSetStatus:
    collision_count: typing.Optional[int]
    conditions: typing.Optional[list[kubernetes.client.V1DaemonSetCondition]]
    current_number_scheduled: int
    desired_number_scheduled: int
    number_available: typing.Optional[int]
    number_misscheduled: int
    number_ready: int
    number_unavailable: typing.Optional[int]
    observed_generation: typing.Optional[int]
    updated_number_scheduled: typing.Optional[int]
    def __init__(
        self,
        *,
        collision_count: typing.Optional[int] = ...,
        conditions: typing.Optional[list[kubernetes.client.V1DaemonSetCondition]] = ...,
        current_number_scheduled: int,
        desired_number_scheduled: int,
        number_available: typing.Optional[int] = ...,
        number_misscheduled: int,
        number_ready: int,
        number_unavailable: typing.Optional[int] = ...,
        observed_generation: typing.Optional[int] = ...,
        updated_number_scheduled: typing.Optional[int] = ...
    ) -> None: ...
    def to_dict(self) -> V1DaemonSetStatusDict: ...

class V1DaemonSetStatusDict(typing.TypedDict, total=False):
    collisionCount: typing.Optional[int]
    conditions: typing.Optional[list[kubernetes.client.V1DaemonSetConditionDict]]
    currentNumberScheduled: int
    desiredNumberScheduled: int
    numberAvailable: typing.Optional[int]
    numberMisscheduled: int
    numberReady: int
    numberUnavailable: typing.Optional[int]
    observedGeneration: typing.Optional[int]
    updatedNumberScheduled: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1CustomResourceSubresources:
    scale: typing.Optional[kubernetes.client.V1CustomResourceSubresourceScale]
    status: typing.Optional[typing.Any]
    def __init__(
        self,
        *,
        scale: typing.Optional[
            kubernetes.client.V1CustomResourceSubresourceScale
        ] = ...,
        status: typing.Optional[typing.Any] = ...
    ) -> None: ...
    def to_dict(self) -> V1CustomResourceSubresourcesDict: ...

class V1CustomResourceSubresourcesDict(typing.TypedDict, total=False):
    scale: typing.Optional[kubernetes.client.V1CustomResourceSubresourceScaleDict]
    status: typing.Optional[typing.Any]



import datetime
import typing

import kubernetes.client

class V1ServicePort:
    app_protocol: typing.Optional[str]
    name: typing.Optional[str]
    node_port: typing.Optional[int]
    port: int
    protocol: typing.Optional[str]
    target_port: typing.Optional[typing.Any]
    def __init__(
        self,
        *,
        app_protocol: typing.Optional[str] = ...,
        name: typing.Optional[str] = ...,
        node_port: typing.Optional[int] = ...,
        port: int,
        protocol: typing.Optional[str] = ...,
        target_port: typing.Optional[typing.Any] = ...
    ) -> None: ...
    def to_dict(self) -> V1ServicePortDict: ...

class V1ServicePortDict(typing.TypedDict, total=False):
    appProtocol: typing.Optional[str]
    name: typing.Optional[str]
    nodePort: typing.Optional[int]
    port: int
    protocol: typing.Optional[str]
    targetPort: typing.Optional[typing.Any]



import datetime
import typing

import kubernetes.client

class V1LimitRangeItem:
    default: typing.Optional[dict[str, str]]
    default_request: typing.Optional[dict[str, str]]
    max: typing.Optional[dict[str, str]]
    max_limit_request_ratio: typing.Optional[dict[str, str]]
    min: typing.Optional[dict[str, str]]
    type: str
    def __init__(
        self,
        *,
        default: typing.Optional[dict[str, str]] = ...,
        default_request: typing.Optional[dict[str, str]] = ...,
        max: typing.Optional[dict[str, str]] = ...,
        max_limit_request_ratio: typing.Optional[dict[str, str]] = ...,
        min: typing.Optional[dict[str, str]] = ...,
        type: str
    ) -> None: ...
    def to_dict(self) -> V1LimitRangeItemDict: ...

class V1LimitRangeItemDict(typing.TypedDict, total=False):
    default: typing.Optional[dict[str, str]]
    defaultRequest: typing.Optional[dict[str, str]]
    max: typing.Optional[dict[str, str]]
    maxLimitRequestRatio: typing.Optional[dict[str, str]]
    min: typing.Optional[dict[str, str]]
    type: str



import datetime
import typing

import kubernetes.client

class V2beta2MetricIdentifier:
    name: str
    selector: typing.Optional[kubernetes.client.V1LabelSelector]
    def __init__(
        self,
        *,
        name: str,
        selector: typing.Optional[kubernetes.client.V1LabelSelector] = ...
    ) -> None: ...
    def to_dict(self) -> V2beta2MetricIdentifierDict: ...

class V2beta2MetricIdentifierDict(typing.TypedDict, total=False):
    name: str
    selector: typing.Optional[kubernetes.client.V1LabelSelectorDict]



import datetime
import typing

import kubernetes.client

class V1DaemonEndpoint:
    port: int
    def __init__(self, *, port: int) -> None: ...
    def to_dict(self) -> V1DaemonEndpointDict: ...

class V1DaemonEndpointDict(typing.TypedDict, total=False):
    Port: int



import datetime
import typing

import kubernetes.client

class V1NodeConfigSource:
    config_map: typing.Optional[kubernetes.client.V1ConfigMapNodeConfigSource]
    def __init__(
        self,
        *,
        config_map: typing.Optional[kubernetes.client.V1ConfigMapNodeConfigSource] = ...
    ) -> None: ...
    def to_dict(self) -> V1NodeConfigSourceDict: ...

class V1NodeConfigSourceDict(typing.TypedDict, total=False):
    configMap: typing.Optional[kubernetes.client.V1ConfigMapNodeConfigSourceDict]



import datetime
import typing

import kubernetes.client

class VersionInfo:
    build_date: str
    compiler: str
    git_commit: str
    git_tree_state: str
    git_version: str
    go_version: str
    major: str
    minor: str
    platform: str
    def __init__(
        self,
        *,
        build_date: str,
        compiler: str,
        git_commit: str,
        git_tree_state: str,
        git_version: str,
        go_version: str,
        major: str,
        minor: str,
        platform: str
    ) -> None: ...
    def to_dict(self) -> VersionInfoDict: ...

class VersionInfoDict(typing.TypedDict, total=False):
    buildDate: str
    compiler: str
    gitCommit: str
    gitTreeState: str
    gitVersion: str
    goVersion: str
    major: str
    minor: str
    platform: str



import datetime
import typing

import kubernetes.client

class V1ConfigMapVolumeSource:
    default_mode: typing.Optional[int]
    items: typing.Optional[list[kubernetes.client.V1KeyToPath]]
    name: typing.Optional[str]
    optional: typing.Optional[bool]
    def __init__(
        self,
        *,
        default_mode: typing.Optional[int] = ...,
        items: typing.Optional[list[kubernetes.client.V1KeyToPath]] = ...,
        name: typing.Optional[str] = ...,
        optional: typing.Optional[bool] = ...
    ) -> None: ...
    def to_dict(self) -> V1ConfigMapVolumeSourceDict: ...

class V1ConfigMapVolumeSourceDict(typing.TypedDict, total=False):
    defaultMode: typing.Optional[int]
    items: typing.Optional[list[kubernetes.client.V1KeyToPathDict]]
    name: typing.Optional[str]
    optional: typing.Optional[bool]



import datetime
import typing

import kubernetes.client

class V1PodSpec:
    active_deadline_seconds: typing.Optional[int]
    affinity: typing.Optional[kubernetes.client.V1Affinity]
    automount_service_account_token: typing.Optional[bool]
    containers: list[kubernetes.client.V1Container]
    dns_config: typing.Optional[kubernetes.client.V1PodDNSConfig]
    dns_policy: typing.Optional[str]
    enable_service_links: typing.Optional[bool]
    ephemeral_containers: typing.Optional[list[kubernetes.client.V1EphemeralContainer]]
    host_aliases: typing.Optional[list[kubernetes.client.V1HostAlias]]
    host_ipc: typing.Optional[bool]
    host_network: typing.Optional[bool]
    host_pid: typing.Optional[bool]
    hostname: typing.Optional[str]
    image_pull_secrets: typing.Optional[list[kubernetes.client.V1LocalObjectReference]]
    init_containers: typing.Optional[list[kubernetes.client.V1Container]]
    node_name: typing.Optional[str]
    node_selector: typing.Optional[dict[str, str]]
    overhead: typing.Optional[dict[str, str]]
    preemption_policy: typing.Optional[str]
    priority: typing.Optional[int]
    priority_class_name: typing.Optional[str]
    readiness_gates: typing.Optional[list[kubernetes.client.V1PodReadinessGate]]
    restart_policy: typing.Optional[str]
    runtime_class_name: typing.Optional[str]
    scheduler_name: typing.Optional[str]
    security_context: typing.Optional[kubernetes.client.V1PodSecurityContext]
    service_account: typing.Optional[str]
    service_account_name: typing.Optional[str]
    set_hostname_as_fqdn: typing.Optional[bool]
    share_process_namespace: typing.Optional[bool]
    subdomain: typing.Optional[str]
    termination_grace_period_seconds: typing.Optional[int]
    tolerations: typing.Optional[list[kubernetes.client.V1Toleration]]
    topology_spread_constraints: typing.Optional[
        list[kubernetes.client.V1TopologySpreadConstraint]
    ]
    volumes: typing.Optional[list[kubernetes.client.V1Volume]]
    def __init__(
        self,
        *,
        active_deadline_seconds: typing.Optional[int] = ...,
        affinity: typing.Optional[kubernetes.client.V1Affinity] = ...,
        automount_service_account_token: typing.Optional[bool] = ...,
        containers: list[kubernetes.client.V1Container],
        dns_config: typing.Optional[kubernetes.client.V1PodDNSConfig] = ...,
        dns_policy: typing.Optional[str] = ...,
        enable_service_links: typing.Optional[bool] = ...,
        ephemeral_containers: typing.Optional[
            list[kubernetes.client.V1EphemeralContainer]
        ] = ...,
        host_aliases: typing.Optional[list[kubernetes.client.V1HostAlias]] = ...,
        host_ipc: typing.Optional[bool] = ...,
        host_network: typing.Optional[bool] = ...,
        host_pid: typing.Optional[bool] = ...,
        hostname: typing.Optional[str] = ...,
        image_pull_secrets: typing.Optional[
            list[kubernetes.client.V1LocalObjectReference]
        ] = ...,
        init_containers: typing.Optional[list[kubernetes.client.V1Container]] = ...,
        node_name: typing.Optional[str] = ...,
        node_selector: typing.Optional[dict[str, str]] = ...,
        overhead: typing.Optional[dict[str, str]] = ...,
        preemption_policy: typing.Optional[str] = ...,
        priority: typing.Optional[int] = ...,
        priority_class_name: typing.Optional[str] = ...,
        readiness_gates: typing.Optional[
            list[kubernetes.client.V1PodReadinessGate]
        ] = ...,
        restart_policy: typing.Optional[str] = ...,
        runtime_class_name: typing.Optional[str] = ...,
        scheduler_name: typing.Optional[str] = ...,
        security_context: typing.Optional[kubernetes.client.V1PodSecurityContext] = ...,
        service_account: typing.Optional[str] = ...,
        service_account_name: typing.Optional[str] = ...,
        set_hostname_as_fqdn: typing.Optional[bool] = ...,
        share_process_namespace: typing.Optional[bool] = ...,
        subdomain: typing.Optional[str] = ...,
        termination_grace_period_seconds: typing.Optional[int] = ...,
        tolerations: typing.Optional[list[kubernetes.client.V1Toleration]] = ...,
        topology_spread_constraints: typing.Optional[
            list[kubernetes.client.V1TopologySpreadConstraint]
        ] = ...,
        volumes: typing.Optional[list[kubernetes.client.V1Volume]] = ...
    ) -> None: ...
    def to_dict(self) -> V1PodSpecDict: ...

class V1PodSpecDict(typing.TypedDict, total=False):
    activeDeadlineSeconds: typing.Optional[int]
    affinity: typing.Optional[kubernetes.client.V1AffinityDict]
    automountServiceAccountToken: typing.Optional[bool]
    containers: list[kubernetes.client.V1ContainerDict]
    dnsConfig: typing.Optional[kubernetes.client.V1PodDNSConfigDict]
    dnsPolicy: typing.Optional[str]
    enableServiceLinks: typing.Optional[bool]
    ephemeralContainers: typing.Optional[
        list[kubernetes.client.V1EphemeralContainerDict]
    ]
    hostAliases: typing.Optional[list[kubernetes.client.V1HostAliasDict]]
    hostIPC: typing.Optional[bool]
    hostNetwork: typing.Optional[bool]
    hostPID: typing.Optional[bool]
    hostname: typing.Optional[str]
    imagePullSecrets: typing.Optional[
        list[kubernetes.client.V1LocalObjectReferenceDict]
    ]
    initContainers: typing.Optional[list[kubernetes.client.V1ContainerDict]]
    nodeName: typing.Optional[str]
    nodeSelector: typing.Optional[dict[str, str]]
    overhead: typing.Optional[dict[str, str]]
    preemptionPolicy: typing.Optional[str]
    priority: typing.Optional[int]
    priorityClassName: typing.Optional[str]
    readinessGates: typing.Optional[list[kubernetes.client.V1PodReadinessGateDict]]
    restartPolicy: typing.Optional[str]
    runtimeClassName: typing.Optional[str]
    schedulerName: typing.Optional[str]
    securityContext: typing.Optional[kubernetes.client.V1PodSecurityContextDict]
    serviceAccount: typing.Optional[str]
    serviceAccountName: typing.Optional[str]
    setHostnameAsFQDN: typing.Optional[bool]
    shareProcessNamespace: typing.Optional[bool]
    subdomain: typing.Optional[str]
    terminationGracePeriodSeconds: typing.Optional[int]
    tolerations: typing.Optional[list[kubernetes.client.V1TolerationDict]]
    topologySpreadConstraints: typing.Optional[
        list[kubernetes.client.V1TopologySpreadConstraintDict]
    ]
    volumes: typing.Optional[list[kubernetes.client.V1VolumeDict]]



import datetime
import typing

import kubernetes.client

class V1beta1APIServiceSpec:
    ca_bundle: typing.Optional[str]
    group: typing.Optional[str]
    group_priority_minimum: int
    insecure_skip_tls_verify: typing.Optional[bool]
    service: typing.Optional[kubernetes.client.ApiregistrationV1beta1ServiceReference]
    version: typing.Optional[str]
    version_priority: int
    def __init__(
        self,
        *,
        ca_bundle: typing.Optional[str] = ...,
        group: typing.Optional[str] = ...,
        group_priority_minimum: int,
        insecure_skip_tls_verify: typing.Optional[bool] = ...,
        service: typing.Optional[
            kubernetes.client.ApiregistrationV1beta1ServiceReference
        ] = ...,
        version: typing.Optional[str] = ...,
        version_priority: int
    ) -> None: ...
    def to_dict(self) -> V1beta1APIServiceSpecDict: ...

class V1beta1APIServiceSpecDict(typing.TypedDict, total=False):
    caBundle: typing.Optional[str]
    group: typing.Optional[str]
    groupPriorityMinimum: int
    insecureSkipTLSVerify: typing.Optional[bool]
    service: typing.Optional[
        kubernetes.client.ApiregistrationV1beta1ServiceReferenceDict
    ]
    version: typing.Optional[str]
    versionPriority: int



import datetime
import typing

import kubernetes.client

class V1LoadBalancerIngress:
    hostname: typing.Optional[str]
    ip: typing.Optional[str]
    ports: typing.Optional[list[kubernetes.client.V1PortStatus]]
    def __init__(
        self,
        *,
        hostname: typing.Optional[str] = ...,
        ip: typing.Optional[str] = ...,
        ports: typing.Optional[list[kubernetes.client.V1PortStatus]] = ...
    ) -> None: ...
    def to_dict(self) -> V1LoadBalancerIngressDict: ...

class V1LoadBalancerIngressDict(typing.TypedDict, total=False):
    hostname: typing.Optional[str]
    ip: typing.Optional[str]
    ports: typing.Optional[list[kubernetes.client.V1PortStatusDict]]



import datetime
import typing

import kubernetes.client

class V1beta1CertificateSigningRequestStatus:
    certificate: typing.Optional[str]
    conditions: typing.Optional[
        list[kubernetes.client.V1beta1CertificateSigningRequestCondition]
    ]
    def __init__(
        self,
        *,
        certificate: typing.Optional[str] = ...,
        conditions: typing.Optional[
            list[kubernetes.client.V1beta1CertificateSigningRequestCondition]
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1CertificateSigningRequestStatusDict: ...

class V1beta1CertificateSigningRequestStatusDict(typing.TypedDict, total=False):
    certificate: typing.Optional[str]
    conditions: typing.Optional[
        list[kubernetes.client.V1beta1CertificateSigningRequestConditionDict]
    ]



import datetime
import typing

import kubernetes.client

class V1APIGroup:
    api_version: typing.Optional[str]
    kind: typing.Optional[str]
    name: str
    preferred_version: typing.Optional[kubernetes.client.V1GroupVersionForDiscovery]
    server_address_by_client_cid_rs: typing.Optional[
        list[kubernetes.client.V1ServerAddressByClientCIDR]
    ]
    versions: list[kubernetes.client.V1GroupVersionForDiscovery]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        name: str,
        preferred_version: typing.Optional[
            kubernetes.client.V1GroupVersionForDiscovery
        ] = ...,
        server_address_by_client_cid_rs: typing.Optional[
            list[kubernetes.client.V1ServerAddressByClientCIDR]
        ] = ...,
        versions: list[kubernetes.client.V1GroupVersionForDiscovery]
    ) -> None: ...
    def to_dict(self) -> V1APIGroupDict: ...

class V1APIGroupDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    kind: typing.Optional[str]
    name: str
    preferredVersion: typing.Optional[kubernetes.client.V1GroupVersionForDiscoveryDict]
    serverAddressByClientCIDRs: typing.Optional[
        list[kubernetes.client.V1ServerAddressByClientCIDRDict]
    ]
    versions: list[kubernetes.client.V1GroupVersionForDiscoveryDict]



import datetime
import typing

import kubernetes.client

class V1beta1RuntimeClassStrategyOptions:
    allowed_runtime_class_names: list[str]
    default_runtime_class_name: typing.Optional[str]
    def __init__(
        self,
        *,
        allowed_runtime_class_names: list[str],
        default_runtime_class_name: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1RuntimeClassStrategyOptionsDict: ...

class V1beta1RuntimeClassStrategyOptionsDict(typing.TypedDict, total=False):
    allowedRuntimeClassNames: list[str]
    defaultRuntimeClassName: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1PersistentVolumeClaimSpec:
    access_modes: typing.Optional[list[str]]
    data_source: typing.Optional[kubernetes.client.V1TypedLocalObjectReference]
    resources: typing.Optional[kubernetes.client.V1ResourceRequirements]
    selector: typing.Optional[kubernetes.client.V1LabelSelector]
    storage_class_name: typing.Optional[str]
    volume_mode: typing.Optional[str]
    volume_name: typing.Optional[str]
    def __init__(
        self,
        *,
        access_modes: typing.Optional[list[str]] = ...,
        data_source: typing.Optional[
            kubernetes.client.V1TypedLocalObjectReference
        ] = ...,
        resources: typing.Optional[kubernetes.client.V1ResourceRequirements] = ...,
        selector: typing.Optional[kubernetes.client.V1LabelSelector] = ...,
        storage_class_name: typing.Optional[str] = ...,
        volume_mode: typing.Optional[str] = ...,
        volume_name: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1PersistentVolumeClaimSpecDict: ...

class V1PersistentVolumeClaimSpecDict(typing.TypedDict, total=False):
    accessModes: typing.Optional[list[str]]
    dataSource: typing.Optional[kubernetes.client.V1TypedLocalObjectReferenceDict]
    resources: typing.Optional[kubernetes.client.V1ResourceRequirementsDict]
    selector: typing.Optional[kubernetes.client.V1LabelSelectorDict]
    storageClassName: typing.Optional[str]
    volumeMode: typing.Optional[str]
    volumeName: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1beta1SelfSubjectRulesReviewSpec:
    namespace: typing.Optional[str]
    def __init__(self, *, namespace: typing.Optional[str] = ...) -> None: ...
    def to_dict(self) -> V1beta1SelfSubjectRulesReviewSpecDict: ...

class V1beta1SelfSubjectRulesReviewSpecDict(typing.TypedDict, total=False):
    namespace: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V2beta1ResourceMetricStatus:
    current_average_utilization: typing.Optional[int]
    current_average_value: str
    name: str
    def __init__(
        self,
        *,
        current_average_utilization: typing.Optional[int] = ...,
        current_average_value: str,
        name: str
    ) -> None: ...
    def to_dict(self) -> V2beta1ResourceMetricStatusDict: ...

class V2beta1ResourceMetricStatusDict(typing.TypedDict, total=False):
    currentAverageUtilization: typing.Optional[int]
    currentAverageValue: str
    name: str



import datetime
import typing

import kubernetes.client

class NetworkingV1beta1IngressStatus:
    load_balancer: typing.Optional[kubernetes.client.V1LoadBalancerStatus]
    def __init__(
        self,
        *,
        load_balancer: typing.Optional[kubernetes.client.V1LoadBalancerStatus] = ...
    ) -> None: ...
    def to_dict(self) -> NetworkingV1beta1IngressStatusDict: ...

class NetworkingV1beta1IngressStatusDict(typing.TypedDict, total=False):
    loadBalancer: typing.Optional[kubernetes.client.V1LoadBalancerStatusDict]



import datetime
import typing

import kubernetes.client

class V1alpha1StorageVersionCondition:
    last_transition_time: typing.Optional[datetime.datetime]
    message: typing.Optional[str]
    observed_generation: typing.Optional[int]
    reason: str
    status: str
    type: str
    def __init__(
        self,
        *,
        last_transition_time: typing.Optional[datetime.datetime] = ...,
        message: typing.Optional[str] = ...,
        observed_generation: typing.Optional[int] = ...,
        reason: str,
        status: str,
        type: str
    ) -> None: ...
    def to_dict(self) -> V1alpha1StorageVersionConditionDict: ...

class V1alpha1StorageVersionConditionDict(typing.TypedDict, total=False):
    lastTransitionTime: typing.Optional[datetime.datetime]
    message: typing.Optional[str]
    observedGeneration: typing.Optional[int]
    reason: str
    status: str
    type: str



import datetime
import typing

import kubernetes.client

class V1beta1VolumeAttachmentSource:
    inline_volume_spec: typing.Optional[kubernetes.client.V1PersistentVolumeSpec]
    persistent_volume_name: typing.Optional[str]
    def __init__(
        self,
        *,
        inline_volume_spec: typing.Optional[
            kubernetes.client.V1PersistentVolumeSpec
        ] = ...,
        persistent_volume_name: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1VolumeAttachmentSourceDict: ...

class V1beta1VolumeAttachmentSourceDict(typing.TypedDict, total=False):
    inlineVolumeSpec: typing.Optional[kubernetes.client.V1PersistentVolumeSpecDict]
    persistentVolumeName: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1NodeSpec:
    config_source: typing.Optional[kubernetes.client.V1NodeConfigSource]
    external_id: typing.Optional[str]
    pod_cidr: typing.Optional[str]
    pod_cid_rs: typing.Optional[list[str]]
    provider_id: typing.Optional[str]
    taints: typing.Optional[list[kubernetes.client.V1Taint]]
    unschedulable: typing.Optional[bool]
    def __init__(
        self,
        *,
        config_source: typing.Optional[kubernetes.client.V1NodeConfigSource] = ...,
        external_id: typing.Optional[str] = ...,
        pod_cidr: typing.Optional[str] = ...,
        pod_cid_rs: typing.Optional[list[str]] = ...,
        provider_id: typing.Optional[str] = ...,
        taints: typing.Optional[list[kubernetes.client.V1Taint]] = ...,
        unschedulable: typing.Optional[bool] = ...
    ) -> None: ...
    def to_dict(self) -> V1NodeSpecDict: ...

class V1NodeSpecDict(typing.TypedDict, total=False):
    configSource: typing.Optional[kubernetes.client.V1NodeConfigSourceDict]
    externalID: typing.Optional[str]
    podCIDR: typing.Optional[str]
    podCIDRs: typing.Optional[list[str]]
    providerID: typing.Optional[str]
    taints: typing.Optional[list[kubernetes.client.V1TaintDict]]
    unschedulable: typing.Optional[bool]



import datetime
import typing

import kubernetes.client

class V1ClientIPConfig:
    timeout_seconds: typing.Optional[int]
    def __init__(self, *, timeout_seconds: typing.Optional[int] = ...) -> None: ...
    def to_dict(self) -> V1ClientIPConfigDict: ...

class V1ClientIPConfigDict(typing.TypedDict, total=False):
    timeoutSeconds: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V2beta2ContainerResourceMetricStatus:
    container: str
    current: kubernetes.client.V2beta2MetricValueStatus
    name: str
    def __init__(
        self,
        *,
        container: str,
        current: kubernetes.client.V2beta2MetricValueStatus,
        name: str
    ) -> None: ...
    def to_dict(self) -> V2beta2ContainerResourceMetricStatusDict: ...

class V2beta2ContainerResourceMetricStatusDict(typing.TypedDict, total=False):
    container: str
    current: kubernetes.client.V2beta2MetricValueStatusDict
    name: str



import datetime
import typing

import kubernetes.client

class V2beta2HPAScalingRules:
    policies: typing.Optional[list[kubernetes.client.V2beta2HPAScalingPolicy]]
    select_policy: typing.Optional[str]
    stabilization_window_seconds: typing.Optional[int]
    def __init__(
        self,
        *,
        policies: typing.Optional[
            list[kubernetes.client.V2beta2HPAScalingPolicy]
        ] = ...,
        select_policy: typing.Optional[str] = ...,
        stabilization_window_seconds: typing.Optional[int] = ...
    ) -> None: ...
    def to_dict(self) -> V2beta2HPAScalingRulesDict: ...

class V2beta2HPAScalingRulesDict(typing.TypedDict, total=False):
    policies: typing.Optional[list[kubernetes.client.V2beta2HPAScalingPolicyDict]]
    selectPolicy: typing.Optional[str]
    stabilizationWindowSeconds: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1EnvVarSource:
    config_map_key_ref: typing.Optional[kubernetes.client.V1ConfigMapKeySelector]
    field_ref: typing.Optional[kubernetes.client.V1ObjectFieldSelector]
    resource_field_ref: typing.Optional[kubernetes.client.V1ResourceFieldSelector]
    secret_key_ref: typing.Optional[kubernetes.client.V1SecretKeySelector]
    def __init__(
        self,
        *,
        config_map_key_ref: typing.Optional[
            kubernetes.client.V1ConfigMapKeySelector
        ] = ...,
        field_ref: typing.Optional[kubernetes.client.V1ObjectFieldSelector] = ...,
        resource_field_ref: typing.Optional[
            kubernetes.client.V1ResourceFieldSelector
        ] = ...,
        secret_key_ref: typing.Optional[kubernetes.client.V1SecretKeySelector] = ...
    ) -> None: ...
    def to_dict(self) -> V1EnvVarSourceDict: ...

class V1EnvVarSourceDict(typing.TypedDict, total=False):
    configMapKeyRef: typing.Optional[kubernetes.client.V1ConfigMapKeySelectorDict]
    fieldRef: typing.Optional[kubernetes.client.V1ObjectFieldSelectorDict]
    resourceFieldRef: typing.Optional[kubernetes.client.V1ResourceFieldSelectorDict]
    secretKeyRef: typing.Optional[kubernetes.client.V1SecretKeySelectorDict]



from kubernetes.client.api.admissionregistration_api import \
    AdmissionregistrationApi as AdmissionregistrationApi
from kubernetes.client.api.admissionregistration_v1_api import \
    AdmissionregistrationV1Api as AdmissionregistrationV1Api
from kubernetes.client.api.admissionregistration_v1beta1_api import \
    AdmissionregistrationV1beta1Api as AdmissionregistrationV1beta1Api
from kubernetes.client.api.apiextensions_api import \
    ApiextensionsApi as ApiextensionsApi
from kubernetes.client.api.apiextensions_v1_api import \
    ApiextensionsV1Api as ApiextensionsV1Api
from kubernetes.client.api.apiextensions_v1beta1_api import \
    ApiextensionsV1beta1Api as ApiextensionsV1beta1Api
from kubernetes.client.api.apiregistration_api import \
    ApiregistrationApi as ApiregistrationApi
from kubernetes.client.api.apiregistration_v1_api import \
    ApiregistrationV1Api as ApiregistrationV1Api
from kubernetes.client.api.apiregistration_v1beta1_api import \
    ApiregistrationV1beta1Api as ApiregistrationV1beta1Api
from kubernetes.client.api.apis_api import ApisApi as ApisApi
from kubernetes.client.api.apps_api import AppsApi as AppsApi
from kubernetes.client.api.apps_v1_api import AppsV1Api as AppsV1Api
from kubernetes.client.api.authentication_api import \
    AuthenticationApi as AuthenticationApi
from kubernetes.client.api.authentication_v1_api import \
    AuthenticationV1Api as AuthenticationV1Api
from kubernetes.client.api.authentication_v1beta1_api import \
    AuthenticationV1beta1Api as AuthenticationV1beta1Api
from kubernetes.client.api.authorization_api import \
    AuthorizationApi as AuthorizationApi
from kubernetes.client.api.authorization_v1_api import \
    AuthorizationV1Api as AuthorizationV1Api
from kubernetes.client.api.authorization_v1beta1_api import \
    AuthorizationV1beta1Api as AuthorizationV1beta1Api
from kubernetes.client.api.autoscaling_api import \
    AutoscalingApi as AutoscalingApi
from kubernetes.client.api.autoscaling_v1_api import \
    AutoscalingV1Api as AutoscalingV1Api
from kubernetes.client.api.autoscaling_v2beta1_api import \
    AutoscalingV2beta1Api as AutoscalingV2beta1Api
from kubernetes.client.api.autoscaling_v2beta2_api import \
    AutoscalingV2beta2Api as AutoscalingV2beta2Api
from kubernetes.client.api.batch_api import BatchApi as BatchApi
from kubernetes.client.api.batch_v1_api import BatchV1Api as BatchV1Api
from kubernetes.client.api.batch_v1beta1_api import \
    BatchV1beta1Api as BatchV1beta1Api
from kubernetes.client.api.batch_v2alpha1_api import \
    BatchV2alpha1Api as BatchV2alpha1Api
from kubernetes.client.api.certificates_api import \
    CertificatesApi as CertificatesApi
from kubernetes.client.api.certificates_v1_api import \
    CertificatesV1Api as CertificatesV1Api
from kubernetes.client.api.certificates_v1beta1_api import \
    CertificatesV1beta1Api as CertificatesV1beta1Api
from kubernetes.client.api.coordination_api import \
    CoordinationApi as CoordinationApi
from kubernetes.client.api.coordination_v1_api import \
    CoordinationV1Api as CoordinationV1Api
from kubernetes.client.api.coordination_v1beta1_api import \
    CoordinationV1beta1Api as CoordinationV1beta1Api
from kubernetes.client.api.core_api import CoreApi as CoreApi
from kubernetes.client.api.core_v1_api import CoreV1Api as CoreV1Api
from kubernetes.client.api.custom_objects_api import \
    CustomObjectsApi as CustomObjectsApi
from kubernetes.client.api.discovery_api import DiscoveryApi as DiscoveryApi
from kubernetes.client.api.discovery_v1beta1_api import \
    DiscoveryV1beta1Api as DiscoveryV1beta1Api
from kubernetes.client.api.events_api import EventsApi as EventsApi
from kubernetes.client.api.events_v1_api import EventsV1Api as EventsV1Api
from kubernetes.client.api.events_v1beta1_api import \
    EventsV1beta1Api as EventsV1beta1Api
from kubernetes.client.api.extensions_api import ExtensionsApi as ExtensionsApi
from kubernetes.client.api.extensions_v1beta1_api import \
    ExtensionsV1beta1Api as ExtensionsV1beta1Api
from kubernetes.client.api.flowcontrolApiserver_api import \
    FlowcontrolApiserverApi as FlowcontrolApiserverApi
from kubernetes.client.api.flowcontrolApiserver_v1alpha1_api import \
    FlowcontrolApiserverV1alpha1Api as FlowcontrolApiserverV1alpha1Api
from kubernetes.client.api.flowcontrolApiserver_v1beta1_api import \
    FlowcontrolApiserverV1beta1Api as FlowcontrolApiserverV1beta1Api
from kubernetes.client.api.internalApiserver_api import \
    InternalApiserverApi as InternalApiserverApi
from kubernetes.client.api.internalApiserver_v1alpha1_api import \
    InternalApiserverV1alpha1Api as InternalApiserverV1alpha1Api
from kubernetes.client.api.logs_api import LogsApi as LogsApi
from kubernetes.client.api.networking_api import NetworkingApi as NetworkingApi
from kubernetes.client.api.networking_v1_api import \
    NetworkingV1Api as NetworkingV1Api
from kubernetes.client.api.networking_v1beta1_api import \
    NetworkingV1beta1Api as NetworkingV1beta1Api
from kubernetes.client.api.node_api import NodeApi as NodeApi
from kubernetes.client.api.node_v1_api import NodeV1Api as NodeV1Api
from kubernetes.client.api.node_v1alpha1_api import \
    NodeV1alpha1Api as NodeV1alpha1Api
from kubernetes.client.api.node_v1beta1_api import \
    NodeV1beta1Api as NodeV1beta1Api
from kubernetes.client.api.openid_api import OpenidApi as OpenidApi
from kubernetes.client.api.policy_api import PolicyApi as PolicyApi
from kubernetes.client.api.policy_v1beta1_api import \
    PolicyV1beta1Api as PolicyV1beta1Api
from kubernetes.client.api.rbacAuthorization_api import \
    RbacAuthorizationApi as RbacAuthorizationApi
from kubernetes.client.api.rbacAuthorization_v1_api import \
    RbacAuthorizationV1Api as RbacAuthorizationV1Api
from kubernetes.client.api.rbacAuthorization_v1alpha1_api import \
    RbacAuthorizationV1alpha1Api as RbacAuthorizationV1alpha1Api
from kubernetes.client.api.rbacAuthorization_v1beta1_api import \
    RbacAuthorizationV1beta1Api as RbacAuthorizationV1beta1Api
from kubernetes.client.api.scheduling_api import SchedulingApi as SchedulingApi
from kubernetes.client.api.scheduling_v1_api import \
    SchedulingV1Api as SchedulingV1Api
from kubernetes.client.api.scheduling_v1alpha1_api import \
    SchedulingV1alpha1Api as SchedulingV1alpha1Api
from kubernetes.client.api.scheduling_v1beta1_api import \
    SchedulingV1beta1Api as SchedulingV1beta1Api
from kubernetes.client.api.storage_api import StorageApi as StorageApi
from kubernetes.client.api.storage_v1_api import StorageV1Api as StorageV1Api
from kubernetes.client.api.storage_v1alpha1_api import \
    StorageV1alpha1Api as StorageV1alpha1Api
from kubernetes.client.api.storage_v1beta1_api import \
    StorageV1beta1Api as StorageV1beta1Api
from kubernetes.client.api.version_api import VersionApi as VersionApi
from kubernetes.client.api.WellKnown_api import WellKnownApi as WellKnownApi



import datetime
import typing

import kubernetes.client

class V1NodeSelector:
    node_selector_terms: list[kubernetes.client.V1NodeSelectorTerm]
    def __init__(
        self, *, node_selector_terms: list[kubernetes.client.V1NodeSelectorTerm]
    ) -> None: ...
    def to_dict(self) -> V1NodeSelectorDict: ...

class V1NodeSelectorDict(typing.TypedDict, total=False):
    nodeSelectorTerms: list[kubernetes.client.V1NodeSelectorTermDict]



import datetime
import typing

import kubernetes.client

class V1CustomResourceDefinitionStatus:
    accepted_names: typing.Optional[kubernetes.client.V1CustomResourceDefinitionNames]
    conditions: typing.Optional[
        list[kubernetes.client.V1CustomResourceDefinitionCondition]
    ]
    stored_versions: typing.Optional[list[str]]
    def __init__(
        self,
        *,
        accepted_names: typing.Optional[
            kubernetes.client.V1CustomResourceDefinitionNames
        ] = ...,
        conditions: typing.Optional[
            list[kubernetes.client.V1CustomResourceDefinitionCondition]
        ] = ...,
        stored_versions: typing.Optional[list[str]] = ...
    ) -> None: ...
    def to_dict(self) -> V1CustomResourceDefinitionStatusDict: ...

class V1CustomResourceDefinitionStatusDict(typing.TypedDict, total=False):
    acceptedNames: typing.Optional[
        kubernetes.client.V1CustomResourceDefinitionNamesDict
    ]
    conditions: typing.Optional[
        list[kubernetes.client.V1CustomResourceDefinitionConditionDict]
    ]
    storedVersions: typing.Optional[list[str]]



import datetime
import typing

import kubernetes.client

class V1beta1SubjectRulesReviewStatus:
    evaluation_error: typing.Optional[str]
    incomplete: bool
    non_resource_rules: list[kubernetes.client.V1beta1NonResourceRule]
    resource_rules: list[kubernetes.client.V1beta1ResourceRule]
    def __init__(
        self,
        *,
        evaluation_error: typing.Optional[str] = ...,
        incomplete: bool,
        non_resource_rules: list[kubernetes.client.V1beta1NonResourceRule],
        resource_rules: list[kubernetes.client.V1beta1ResourceRule]
    ) -> None: ...
    def to_dict(self) -> V1beta1SubjectRulesReviewStatusDict: ...

class V1beta1SubjectRulesReviewStatusDict(typing.TypedDict, total=False):
    evaluationError: typing.Optional[str]
    incomplete: bool
    nonResourceRules: list[kubernetes.client.V1beta1NonResourceRuleDict]
    resourceRules: list[kubernetes.client.V1beta1ResourceRuleDict]



import datetime
import typing

import kubernetes.client

class V1IngressServiceBackend:
    name: str
    port: typing.Optional[kubernetes.client.V1ServiceBackendPort]
    def __init__(
        self,
        *,
        name: str,
        port: typing.Optional[kubernetes.client.V1ServiceBackendPort] = ...
    ) -> None: ...
    def to_dict(self) -> V1IngressServiceBackendDict: ...

class V1IngressServiceBackendDict(typing.TypedDict, total=False):
    name: str
    port: typing.Optional[kubernetes.client.V1ServiceBackendPortDict]



import datetime
import typing

import kubernetes.client

class V1CSINodeSpec:
    drivers: list[kubernetes.client.V1CSINodeDriver]
    def __init__(self, *, drivers: list[kubernetes.client.V1CSINodeDriver]) -> None: ...
    def to_dict(self) -> V1CSINodeSpecDict: ...

class V1CSINodeSpecDict(typing.TypedDict, total=False):
    drivers: list[kubernetes.client.V1CSINodeDriverDict]



import datetime
import typing

import kubernetes.client

class V1VolumeError:
    message: typing.Optional[str]
    time: typing.Optional[datetime.datetime]
    def __init__(
        self,
        *,
        message: typing.Optional[str] = ...,
        time: typing.Optional[datetime.datetime] = ...
    ) -> None: ...
    def to_dict(self) -> V1VolumeErrorDict: ...

class V1VolumeErrorDict(typing.TypedDict, total=False):
    message: typing.Optional[str]
    time: typing.Optional[datetime.datetime]



import datetime
import typing

import kubernetes.client

class V1alpha1FlowDistinguisherMethod:
    type: str
    def __init__(self, *, type: str) -> None: ...
    def to_dict(self) -> V1alpha1FlowDistinguisherMethodDict: ...

class V1alpha1FlowDistinguisherMethodDict(typing.TypedDict, total=False):
    type: str



import datetime
import typing

import kubernetes.client

class V1LimitRangeSpec:
    limits: list[kubernetes.client.V1LimitRangeItem]
    def __init__(self, *, limits: list[kubernetes.client.V1LimitRangeItem]) -> None: ...
    def to_dict(self) -> V1LimitRangeSpecDict: ...

class V1LimitRangeSpecDict(typing.TypedDict, total=False):
    limits: list[kubernetes.client.V1LimitRangeItemDict]



import datetime
import typing

import kubernetes.client

class V1FlockerVolumeSource:
    dataset_name: typing.Optional[str]
    dataset_uuid: typing.Optional[str]
    def __init__(
        self,
        *,
        dataset_name: typing.Optional[str] = ...,
        dataset_uuid: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1FlockerVolumeSourceDict: ...

class V1FlockerVolumeSourceDict(typing.TypedDict, total=False):
    datasetName: typing.Optional[str]
    datasetUUID: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1GlusterfsPersistentVolumeSource:
    endpoints: str
    endpoints_namespace: typing.Optional[str]
    path: str
    read_only: typing.Optional[bool]
    def __init__(
        self,
        *,
        endpoints: str,
        endpoints_namespace: typing.Optional[str] = ...,
        path: str,
        read_only: typing.Optional[bool] = ...
    ) -> None: ...
    def to_dict(self) -> V1GlusterfsPersistentVolumeSourceDict: ...

class V1GlusterfsPersistentVolumeSourceDict(typing.TypedDict, total=False):
    endpoints: str
    endpointsNamespace: typing.Optional[str]
    path: str
    readOnly: typing.Optional[bool]



import datetime
import typing

import kubernetes.client

class V1MutatingWebhook:
    admission_review_versions: list[str]
    client_config: kubernetes.client.AdmissionregistrationV1WebhookClientConfig
    failure_policy: typing.Optional[str]
    match_policy: typing.Optional[str]
    name: str
    namespace_selector: typing.Optional[kubernetes.client.V1LabelSelector]
    object_selector: typing.Optional[kubernetes.client.V1LabelSelector]
    reinvocation_policy: typing.Optional[str]
    rules: typing.Optional[list[kubernetes.client.V1RuleWithOperations]]
    side_effects: str
    timeout_seconds: typing.Optional[int]
    def __init__(
        self,
        *,
        admission_review_versions: list[str],
        client_config: kubernetes.client.AdmissionregistrationV1WebhookClientConfig,
        failure_policy: typing.Optional[str] = ...,
        match_policy: typing.Optional[str] = ...,
        name: str,
        namespace_selector: typing.Optional[kubernetes.client.V1LabelSelector] = ...,
        object_selector: typing.Optional[kubernetes.client.V1LabelSelector] = ...,
        reinvocation_policy: typing.Optional[str] = ...,
        rules: typing.Optional[list[kubernetes.client.V1RuleWithOperations]] = ...,
        side_effects: str,
        timeout_seconds: typing.Optional[int] = ...
    ) -> None: ...
    def to_dict(self) -> V1MutatingWebhookDict: ...

class V1MutatingWebhookDict(typing.TypedDict, total=False):
    admissionReviewVersions: list[str]
    clientConfig: kubernetes.client.AdmissionregistrationV1WebhookClientConfigDict
    failurePolicy: typing.Optional[str]
    matchPolicy: typing.Optional[str]
    name: str
    namespaceSelector: typing.Optional[kubernetes.client.V1LabelSelectorDict]
    objectSelector: typing.Optional[kubernetes.client.V1LabelSelectorDict]
    reinvocationPolicy: typing.Optional[str]
    rules: typing.Optional[list[kubernetes.client.V1RuleWithOperationsDict]]
    sideEffects: str
    timeoutSeconds: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1beta1PriorityLevelConfigurationSpec:
    limited: typing.Optional[kubernetes.client.V1beta1LimitedPriorityLevelConfiguration]
    type: str
    def __init__(
        self,
        *,
        limited: typing.Optional[
            kubernetes.client.V1beta1LimitedPriorityLevelConfiguration
        ] = ...,
        type: str
    ) -> None: ...
    def to_dict(self) -> V1beta1PriorityLevelConfigurationSpecDict: ...

class V1beta1PriorityLevelConfigurationSpecDict(typing.TypedDict, total=False):
    limited: typing.Optional[
        kubernetes.client.V1beta1LimitedPriorityLevelConfigurationDict
    ]
    type: str



import datetime
import typing

import kubernetes.client

class V1FCVolumeSource:
    fs_type: typing.Optional[str]
    lun: typing.Optional[int]
    read_only: typing.Optional[bool]
    target_ww_ns: typing.Optional[list[str]]
    wwids: typing.Optional[list[str]]
    def __init__(
        self,
        *,
        fs_type: typing.Optional[str] = ...,
        lun: typing.Optional[int] = ...,
        read_only: typing.Optional[bool] = ...,
        target_ww_ns: typing.Optional[list[str]] = ...,
        wwids: typing.Optional[list[str]] = ...
    ) -> None: ...
    def to_dict(self) -> V1FCVolumeSourceDict: ...

class V1FCVolumeSourceDict(typing.TypedDict, total=False):
    fsType: typing.Optional[str]
    lun: typing.Optional[int]
    readOnly: typing.Optional[bool]
    targetWWNs: typing.Optional[list[str]]
    wwids: typing.Optional[list[str]]



import datetime
import typing

import kubernetes.client

class V1NodeSystemInfo:
    architecture: str
    boot_id: str
    container_runtime_version: str
    kernel_version: str
    kube_proxy_version: str
    kubelet_version: str
    machine_id: str
    operating_system: str
    os_image: str
    system_uuid: str
    def __init__(
        self,
        *,
        architecture: str,
        boot_id: str,
        container_runtime_version: str,
        kernel_version: str,
        kube_proxy_version: str,
        kubelet_version: str,
        machine_id: str,
        operating_system: str,
        os_image: str,
        system_uuid: str
    ) -> None: ...
    def to_dict(self) -> V1NodeSystemInfoDict: ...

class V1NodeSystemInfoDict(typing.TypedDict, total=False):
    architecture: str
    bootID: str
    containerRuntimeVersion: str
    kernelVersion: str
    kubeProxyVersion: str
    kubeletVersion: str
    machineID: str
    operatingSystem: str
    osImage: str
    systemUUID: str



import datetime
import typing

import kubernetes.client

class V2beta2HPAScalingPolicy:
    period_seconds: int
    type: str
    value: int
    def __init__(self, *, period_seconds: int, type: str, value: int) -> None: ...
    def to_dict(self) -> V2beta2HPAScalingPolicyDict: ...

class V2beta2HPAScalingPolicyDict(typing.TypedDict, total=False):
    periodSeconds: int
    type: str
    value: int



import datetime
import typing

import kubernetes.client

class V1beta1PodSecurityPolicySpec:
    allow_privilege_escalation: typing.Optional[bool]
    allowed_csi_drivers: typing.Optional[
        list[kubernetes.client.V1beta1AllowedCSIDriver]
    ]
    allowed_capabilities: typing.Optional[list[str]]
    allowed_flex_volumes: typing.Optional[
        list[kubernetes.client.V1beta1AllowedFlexVolume]
    ]
    allowed_host_paths: typing.Optional[list[kubernetes.client.V1beta1AllowedHostPath]]
    allowed_proc_mount_types: typing.Optional[list[str]]
    allowed_unsafe_sysctls: typing.Optional[list[str]]
    default_add_capabilities: typing.Optional[list[str]]
    default_allow_privilege_escalation: typing.Optional[bool]
    forbidden_sysctls: typing.Optional[list[str]]
    fs_group: kubernetes.client.V1beta1FSGroupStrategyOptions
    host_ipc: typing.Optional[bool]
    host_network: typing.Optional[bool]
    host_pid: typing.Optional[bool]
    host_ports: typing.Optional[list[kubernetes.client.V1beta1HostPortRange]]
    privileged: typing.Optional[bool]
    read_only_root_filesystem: typing.Optional[bool]
    required_drop_capabilities: typing.Optional[list[str]]
    run_as_group: typing.Optional[kubernetes.client.V1beta1RunAsGroupStrategyOptions]
    run_as_user: kubernetes.client.V1beta1RunAsUserStrategyOptions
    runtime_class: typing.Optional[kubernetes.client.V1beta1RuntimeClassStrategyOptions]
    se_linux: kubernetes.client.V1beta1SELinuxStrategyOptions
    supplemental_groups: kubernetes.client.V1beta1SupplementalGroupsStrategyOptions
    volumes: typing.Optional[list[str]]
    def __init__(
        self,
        *,
        allow_privilege_escalation: typing.Optional[bool] = ...,
        allowed_csi_drivers: typing.Optional[
            list[kubernetes.client.V1beta1AllowedCSIDriver]
        ] = ...,
        allowed_capabilities: typing.Optional[list[str]] = ...,
        allowed_flex_volumes: typing.Optional[
            list[kubernetes.client.V1beta1AllowedFlexVolume]
        ] = ...,
        allowed_host_paths: typing.Optional[
            list[kubernetes.client.V1beta1AllowedHostPath]
        ] = ...,
        allowed_proc_mount_types: typing.Optional[list[str]] = ...,
        allowed_unsafe_sysctls: typing.Optional[list[str]] = ...,
        default_add_capabilities: typing.Optional[list[str]] = ...,
        default_allow_privilege_escalation: typing.Optional[bool] = ...,
        forbidden_sysctls: typing.Optional[list[str]] = ...,
        fs_group: kubernetes.client.V1beta1FSGroupStrategyOptions,
        host_ipc: typing.Optional[bool] = ...,
        host_network: typing.Optional[bool] = ...,
        host_pid: typing.Optional[bool] = ...,
        host_ports: typing.Optional[list[kubernetes.client.V1beta1HostPortRange]] = ...,
        privileged: typing.Optional[bool] = ...,
        read_only_root_filesystem: typing.Optional[bool] = ...,
        required_drop_capabilities: typing.Optional[list[str]] = ...,
        run_as_group: typing.Optional[
            kubernetes.client.V1beta1RunAsGroupStrategyOptions
        ] = ...,
        run_as_user: kubernetes.client.V1beta1RunAsUserStrategyOptions,
        runtime_class: typing.Optional[
            kubernetes.client.V1beta1RuntimeClassStrategyOptions
        ] = ...,
        se_linux: kubernetes.client.V1beta1SELinuxStrategyOptions,
        supplemental_groups: kubernetes.client.V1beta1SupplementalGroupsStrategyOptions,
        volumes: typing.Optional[list[str]] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1PodSecurityPolicySpecDict: ...

class V1beta1PodSecurityPolicySpecDict(typing.TypedDict, total=False):
    allowPrivilegeEscalation: typing.Optional[bool]
    allowedCSIDrivers: typing.Optional[
        list[kubernetes.client.V1beta1AllowedCSIDriverDict]
    ]
    allowedCapabilities: typing.Optional[list[str]]
    allowedFlexVolumes: typing.Optional[
        list[kubernetes.client.V1beta1AllowedFlexVolumeDict]
    ]
    allowedHostPaths: typing.Optional[
        list[kubernetes.client.V1beta1AllowedHostPathDict]
    ]
    allowedProcMountTypes: typing.Optional[list[str]]
    allowedUnsafeSysctls: typing.Optional[list[str]]
    defaultAddCapabilities: typing.Optional[list[str]]
    defaultAllowPrivilegeEscalation: typing.Optional[bool]
    forbiddenSysctls: typing.Optional[list[str]]
    fsGroup: kubernetes.client.V1beta1FSGroupStrategyOptionsDict
    hostIPC: typing.Optional[bool]
    hostNetwork: typing.Optional[bool]
    hostPID: typing.Optional[bool]
    hostPorts: typing.Optional[list[kubernetes.client.V1beta1HostPortRangeDict]]
    privileged: typing.Optional[bool]
    readOnlyRootFilesystem: typing.Optional[bool]
    requiredDropCapabilities: typing.Optional[list[str]]
    runAsGroup: typing.Optional[kubernetes.client.V1beta1RunAsGroupStrategyOptionsDict]
    runAsUser: kubernetes.client.V1beta1RunAsUserStrategyOptionsDict
    runtimeClass: typing.Optional[
        kubernetes.client.V1beta1RuntimeClassStrategyOptionsDict
    ]
    seLinux: kubernetes.client.V1beta1SELinuxStrategyOptionsDict
    supplementalGroups: kubernetes.client.V1beta1SupplementalGroupsStrategyOptionsDict
    volumes: typing.Optional[list[str]]



import datetime
import typing

import kubernetes.client

class NetworkingV1beta1HTTPIngressRuleValue:
    paths: list[kubernetes.client.NetworkingV1beta1HTTPIngressPath]
    def __init__(
        self, *, paths: list[kubernetes.client.NetworkingV1beta1HTTPIngressPath]
    ) -> None: ...
    def to_dict(self) -> NetworkingV1beta1HTTPIngressRuleValueDict: ...

class NetworkingV1beta1HTTPIngressRuleValueDict(typing.TypedDict, total=False):
    paths: list[kubernetes.client.NetworkingV1beta1HTTPIngressPathDict]
